%--------------------------------------------------------------------------  
    function ExtractOCC2DProfile(hfig)
%--------------------------------------------------------------------------    
%
%   Extracts a vertical conductivity profile(s) from an OCCAM2DMT Model
%
%   Assumes REGRHO in figure UserData field is in Ohm-m and that
%   REGZ and REGY are depth and distance in km.
%
%    Kerry Key
%    Scripps Institution of Oceanography
%    University of California, San Diego
%    kkey@ucsd.edu
%
%    Version 1.0 February 23, 2006
%
%--------------------------------------------------------------------------
    D = get(hfig,'UserData');
    
 %  Ask user for y distance or a range ( [y] or [y0:dy:y1]) :
 

    y = inputdlg('Input single y ( y0 ) or range ( y0:dy:y1) in km','Profile Extractor',1);
    if isempty(y)
        return
    elseif isempty(y{:})
        return
    end
    y = eval(y{:});
    ny = length(y);
    
    % simplify the 
    
    % loop through y values and extract and plot the profiles:
    
    figure;
    cc = {'b-' 'g-' 'r-' 'c-' 'm-' 'y-' 'k-' ...
         'b:' 'g:' 'r:' 'c:' 'm:' 'y:' 'k:'   ...
          'b-.' 'g-.' 'r-.' 'c-.' 'm-.' 'y-.' 'k-.' ...
               }; 
     for i = 1:ny
%         % find regy that bounds y(i)
          ii = find( D.REGY(1,:)<=y(i) & D.REGY(2,:)>y(i));    
          jj =semilogx( 10.^[D.REGRHO(ii); D.REGRHO(ii)], [D.REGZ(1,ii);D.REGZ(2,ii)],cc{i}) ; 
          hl(i) = jj(1); % store handle to part of the plotted lines
          axis ij;
          hold on;
         % connect the layer depth intervales: 
          semilogx( 10.^[D.REGRHO(ii(1:end-1)); D.REGRHO(ii(2:end))],...
              [D.REGZ(2,ii(1:end-1));D.REGZ(1,ii(2:end))],cc{i}) ; 

    
     end
    xlabel('Resistivity (ohm-m)');
    ylabel('Depth (km)')
    legend(hl,num2str(y'))
    
% Integrated resistance plot:
%  figure;
%   for i = 1:ny
% %         % find regy that bounds y(i)
%           ii = find( D.REGY(1,:)<=y(i) & D.REGY(2,:)>y(i));   
%           i2 = ~isnan(D.REGRHO(ii));
%           st = 10.^D.REGRHO(ii(i2))*1000.* abs(diff(D.REGZ(:,ii(i2)))); % assumes depth in kilometers
%           cst = cumsum(st);
%           jj =semilogx( cst, mean([D.REGZ(1,ii(i2));D.REGZ(2,ii(i2))]),cc{i}) ;
%           hl(i) = jj(1); % store handle to part of the plotted lines
%           axis ij;
%           hold on;
%   end
%   legend(hl,num2str(y'))
%     xlabel('Integrated Resistance (ohm)');
%     ylabel('Depth (km)')
  