%-------------------------------------------------------------------------------
% plotOccam2DMTResponse
%
% A matlab script to plot OCCAM2DMT model responses
%
% Written by:  Kerry Key
%              Scripps Institution of Oceanography
%              kkey@ucsd.edu
% 
% A few of the subfunctions here are from the Matlab potting routines for Egbert's
% MT response files.
%
% Version 1.0,  2000...
%
% This program is very sloppy and at some point i'll rewrite it.  Limits
% are hardwired in some places.  
%
%
%-------------------------------------------------------------------------------
function plotOccam2DMTResponse(varargin)
%-----------------------------------------------------------------------------------
% GET MODEL RESPONSE FILE
%-----------------------------------------------------------------------------------
if nargin ==0
   [fname, pname]=uigetfile('*','Select OCCAM2DMT Model Response File: ');
   RESP=load(strcat(pname,fname));
else
    if exist(varargin{1},'file')
        RESP=load(varargin{1});
    else
       [p n e v ] = fileparts(varargin{1});
       if exist(n,'file')
           RESP = load(n);
       else
           disp(sprintf('Error, can not open response file: %s',varargin{1}))
       end
    end
end

%------------------------------------------------------------------------------------
% GET DATA FILE
%------------------------------------------------------------------------------------
  % Get file name
  if nargin ==0
    [file, path] =uigetfile('*','Select OCCAM DATA file to plot:  ');
     filename = strcat(path,file);
  else
      filename = varargin{2};
  end
  % Get file contents:
    [datfrm,datdes,nsites,sites,offsts,nfre,freqs, ...
          ndblks,DATA]= readDATA(filename);
    freqs = freqs';
%--------------------------------------------------------------------------------------
% PLOT MODEL RESPONSES AND DATA
%--------------------------------------------------------------------------------------
   h_all=figure;  set(h_all,'position',[10 10 nsites*120 250]);
   h_all_resid=figure;  set(h_all_resid,'position',[10 10 nsites*120 250]);
   Dlims = []; % [1 100000 1 1000];
% DECODE EACH SITE'S DATA AND RESP ARRAYS 	
    for i =1:nsites
	   % EXTRACT SITE'S DATA:
        isite = DATA(:,1) ==i;
		site = DATA(isite,:);
		iTMr = site(:,3) == 5;                    % TM app rho index
		DTMr = [10.^site(iTMr,4),site(iTMr,5) ];  % TM app rho data
        TTMr = 1./freqs(site(iTMr,2));            % TM periods
        DTMr(:,2) = DTMr(:,1).*DTMr(:,2)./.434;   % TM error
		iTMp = site(:,3) == 6;                    % TM phase index  
		DTMp = site(iTMp,4:5);                    % TM phase data  
        TTMp = 1./freqs(site(iTMp,2));            % TM phase periods
		iTEr = site(:,3) == 1;                    % TE app rho index
		DTEr = [10.^site(iTEr,4), site(iTEr,5)];    
        TTEr = 1./freqs(site(iTEr,2));
        DTEr(:,2) = DTEr(:,1).*DTEr(:,2)./.434;
   		iTEp = site(:,3) == 2;                    % TE phase index
		DTEp = site(iTEp,4:5);
        TTEp = 1./freqs(site(iTEp,2));                                              
        iTPr = site(:,3) == 3;                    % Tipper real index
        DTPr = site(iTPr,4:5);
        TTPr = 1./freqs(site(iTPr,2)); 
        iTPi = site(:,3) == 3;                    % Tipper imaginary index
        DTPi = site(iTPi,4:5);
        TTPi = 1./freqs(site(iTPi,2)); 
        
       % Set data plot limits 
        if ~isempty(DTEr) || ~isempty(DTMr)
            Dlims = set_lims([],1./freqs,[DTMr(:,1)' DTEr(:,1)']);
            mx = max(1./freqs); mn = min(1./freqs);
           
          %  Dlims = [Dlims(1) Dlims(2) .1 10000];
        end
        if ~isempty(DTPr) || ~isempty(DTPi)  % Tipper plot limits
             mx = max(1./freqs); mn = min(1./freqs);
            DTlims = [mn/5 mx*5 -1 1 ];
        end 
        
        
        % EXTRACT SITE'S RESP:
        isite = RESP(:,1) ==i;
		site   = RESP(isite,:);
		iTMr   = site(:,3) == 5;
		RTMr   = 10.^site(iTMr,6);
		TMRres = site(iTMr,7);
		iTMp   = site(:,3) == 6;
		RTMp   = site(iTMp,6);
		TMPres = site(iTMp,7);
		iTEr   = site(:,3) == 1;
		RTEr   = 10.^site(iTEr,6);
		TERres = site(iTEr,7);
		iTEp   = site(:,3) == 2;
		RTEp   = site(iTEp,6);
		TEPres = site(iTEp,7);
        
        iTPr   = site(:,3) == 3;
		RTPr   = site(iTPr,6);
		TPRres = site(iTPr,7);
		iTPi   = site(:,3) == 4;
		RTPi   = site(iTPi,6);
		TPIres = site(iTPi,7);
        
         Rlims = Dlims;
%         RTlims =  DTlims;

      %----------------- 
      % Plot up current site as individual figure, and part of all in one
      % figure:
      %--------------
        if ~isempty(DTEr) || ~isempty(DTMr) || ~isempty(DTEp) || ~isempty(DTMp) 
            % TE or TM data present
            % DGM 12/15/2005 - stack the figures
            if exist( 'hlast', 'var' )      % make sure prev plot is selected so
                figure(hlast);              %   getStackedFig() will stack below it.
            end
            hlast = getStackedFig();
            % RHO
            rho_axes = subplot(2,1,1);
            % PLOT DATA
            [xb,yb] = err_log(TTMr,DTMr(:,1),DTMr(:,2),'XLOG',Dlims);
            h_DTM = loglog(TTMr,DTMr(:,1),'rx',xb,yb,'r-');
            if ~isempty(DTMr); hold on; end
            [xb,yb] = err_log(TTEr,DTEr(:,1),DTEr(:,2),'XLOG',Dlims);
            h_DTE = loglog(TTEr,DTEr(:,1),'go', xb,yb,'g-');
            if ~isempty(DTEr); hold on; end
            % PLOT RESP
            h_RTM = loglog(TTMr,RTMr(:,1),'r-' );
            hold on;
            h_RTE = loglog(TTEr,RTEr(:,1),'g-' );
            axis(Dlims);
              % set(gca,'FontWeight','bold','FontSize',12)
               ylabel('App. Resisitivity');
               %text = {'DATA TE' 'DATA TM' 'RESP TE' 'RESP TM'};
               leg_hndle=[];
               text = {};

               if ~isempty(h_DTE)
                    leg_hndle =[leg_hndle, h_DTE(1)];
                    text = [text {'DATA TE'}];
               end
               if ~isempty(h_DTM)
                    leg_hndle = [leg_hndle,h_DTM(1)];
                    text = [text {'DATA TM'}];
               end
               if ~isempty(h_RTE)
                    leg_hndle =[leg_hndle, h_RTE(1)];
                    text = [text {'RESP TE'}];
               end
               if ~isempty(h_RTM)
                    leg_hndle = [leg_hndle,h_RTM(1)];
                    text = [text {'RESP TM'}];
               end
                if ~isempty(leg_hndle)
                    h_leg = legend(leg_hndle,text);
                              set(h_leg,'FontSize',8); 
                end

              title(char(sites(i)));
          % PHASE:
            ph_axes = subplot(2,1,2);
             % PLOT DATA
                Dplims = [Dlims(1) Dlims(2) -25 115];
                [xb,yb] = err_log(TTMp,DTMp(:,1),DTMp(:,2),'XLOG',Dplims);
                lines = semilogx(xb,yb,'r-',TTMp,DTMp(:,1),'rx' );
                if ~isempty(DTMp); hold on; end;
                [xb,yb] = err_log(TTEp,DTEp(:,1),DTEp(:,2),'XLOG',Dplims);
                lines = semilogx(xb,yb,'g-',TTEp,DTEp(:,1),'go' );
                if ~isempty(DTEp); hold on; end
             % PLOT RESP
                 Rlims = [Rlims(1) Rlims(2) -25 115];
                lines = semilogx(TTMp,RTMp(:,1),'r-' );
                hold on;
                lines = semilogx(TTEp,RTEp(:,1),'g-' );
                %set(gca,'FontWeight','bold','FontSize',12)
                xlabel('Period (s)');ylabel('Phase (Degrees)');
                axis(Dplims);
             %make things nice
                set(rho_axes,'ygrid','on','xgrid','on');
                %set(rho_axes,'FontWeight','bold');
                phase_ticks = [-150 -120 -90 -60 -30 0 30 60 90 120 150];
                set(ph_axes,'ygrid','on','xgrid','on','YTickMode','manual',...
                'Ytick',phase_ticks);
            
        end  % TE | TM data figure
        
     % TIPPER FIGURE:  
       if ~isempty(DTPr) || ~isempty(DTPi) 
            if exist( 'hlast', 'var' )      % make sure prev plot is selected so
                figure(hlast);              %   getStackedFig() will stack below it.
            end
            hlast = getStackedFig();  
            
            tpr_axes = subplot(2,1,1);
            set(gca,'xscale','log')
            title(char(sites(i)));
            if ~isempty(DTPr); hold on; end
            [xb,yb] = err_log(TTPr,DTPr(:,1),DTPr(:,2),'XLOG',DTlims);
            lines = semilogx(xb,yb,'r-',TTPr,DTPr(:,1),'rx' );
            lines = semilogx(TTPr,RTPr(:,1),'r-' );
            ylabel('Tipper Real');
            axis(DTlims);
            tpi_axes = subplot(2,1,2);
            if ~isempty(DTPi); hold on; end
            set(gca,'xscale','log')
            [xb,yb] = err_log(TTPi,DTPi(:,1),DTPi(:,2),'XLOG',DTlims);
            lines = semilogx(xb,yb,'r-',TTPi,DTPi(:,1),'rx' );  
            lines = semilogx(TTPi,RTPi(:,1),'r-' );
            ylabel('Tipper Imaginary');
            xlabel('Period(s)')
            axis(DTlims);
       end
           %set(ph_axes,'FontWeight','bold');      
	% PLOT RESIDUALS
% 	  % RHO:
% 	   Rres = subplot(2,2,2);
% 	   h_TMRres = semilogx(TTMr,TMRres,'rx');
%        hold on;
% 	   h_TERres = semilogx(TTEr,TERres,'go');
%        set(Rres,'ygrid','on','xgrid','on');
%        set(Rres,'FontWeight','bold');
% 	   ylabel('Residual');
%        text = {};
%        leg_hndle = [];
%        if ~isempty(h_TERres)
%             leg_hndle =[leg_hndle, h_TERres(1)];
%             text = [text {'TE'}];
%        end
%        if ~isempty(h_TMRres)
%             leg_hndle = [leg_hndle,h_TMRres(1)];
%             text = [text {'TM'}];
%        end
%        h_resleg = legend(leg_hndle,text);
%         % PHASE:
% 	   Pres = subplot(2,2,4);
% 	   h_Pres = semilogx(TTMp,TMPres,'rx',TTEp,TEPres,'go');
% 	    set(Pres,'ygrid','on','xgrid','on');
%             set(Pres,'FontWeight','bold');         
%             xlabel('Period (s)');ylabel('Residual');  
%RHO
    figure(h_all);
    indx = i;
    if indx>ceil(nsites/2);
        indx = indx+ceil(nsites/2);
    end
    %rho_axes = subplot(4,ceil(nsites/2),indx);
    %postion rho axes to be upper 2/3 or so...
    rho_axes = subplot('position',[1/15+1/nsites*(i-1)*.9 .55 1/nsites-1/nsites*.10  .35]);
    if ~isempty(DTMr)
     [xb,yb] = err_log(TTMr,DTMr(:,1),DTMr(:,2),'XLOG',Dlims);
    lines = loglog(xb,yb,'r-',TTMr,DTMr(:,1),'rx' );
    end
    if ~isempty(DTMr); hold on; end
    if ~isempty(DTEr)
    [xb,yb] = err_log(TTEr,DTEr(:,1),DTEr(:,2),'XLOG',Dlims);
    lines = loglog(xb,yb,'g-',TTEr,DTEr(:,1),'go' );
    end
    if ~isempty(DTEr); hold on; end
    axis(Dlims);
    %set(gca,'FontWeight','bold','FontSize',12)
     h_RTM = loglog(TTMr,RTMr(:,1),'r-' );
           hold on;
           h_RTE = loglog(TTEr,RTEr(:,1),'g-' );
%            axis(Dlims);
%            set(gca,'FontWeight','bold','FontSize',11)
%            ylabel('App. Resisitivity');
%     
   % period_ticks = [10 100 1000];
    if i == 1;
         ylabel('App. Resisitivity');
         set(rho_axes,'ygrid','off','xgrid','off',...
             'XTickMode','manual',...
             'xtick',[1 10 100 1000],...
             'xticklabel',[],...
          'YTickMode','manual',...
               'Ytick',[.1 1 10 100 1000 10000]);
   else  
     set(rho_axes,'ygrid','off','xgrid','off',...
                  'YTickMode','manual',...
               'Ytick',[.1 1 10 100 1000 10000],...
             'XTickMode','manual',...
             'xtick',[1 10 100 1000],...
        'Yticklabel',[],'Xticklabel',[]);
    end
   % set(rho_axes,'FontWeight','bold');
    text = strcat(char(sites(i)));     %,': ',' TE = Green, TM = Red');
    title(text)
   %PHASE:
     %ph_axes = subplot(4,ceil(nsites/2),indx+ceil(nsites/2));
     ph_axes = subplot('position',[1/15+1/nsites*(i-1)*.9 .20 1/nsites-1/nsites*.10  .30]);
     Dplims = [Dlims(1) Dlims(2) -25 115];
     if ~isempty(DTMp)
     [xb,yb] = err_log(TTMp,DTMp(:,1),DTMp(:,2),'XLOG',Dplims);
     lines = semilogx(xb,yb,'r-',TTMp,DTMp(:,1),'rx' );
     end
     if ~isempty(DTMp); hold on; end
    if ~isempty(DTEp)
     [xb,yb] = err_log(TTEp,DTEp(:,1),DTEp(:,2),'XLOG',Dplims);
     lines = semilogx(xb,yb,'g-',TTEp,DTEp(:,1),'go' );
    end
      if ~isempty(DTEp); hold on; end
   %resp
            lines = semilogx(TTMp,RTMp(:,1),'r-' );
            hold on;
            lines = semilogx(TTEp,RTEp(:,1),'g-' );
   %  set(gca,'FontWeight','bold','FontSize',12)
     axis(Dplims)
     phase_ticks = [-0,15.,30.,45.,60.,75.,90. 105 120 135 150];
  if i==1
          xlabel('Period (s)','FontSize',12);ylabel('Phase (Degrees)');
           set(ph_axes,'XTickMode','manual',...                     
             'xtick',[1 10 100 1000]);
 %              'Xtick',period_ticks);
      %        'XTickMode','manual',...
          %     'Xtick',period_ticks(1:end-1));
  else
          set(ph_axes,'ygrid','off','xgrid','off','YTickMode','manual',...
              'Ytick',phase_ticks,'Yticklabel',[],...
              'XTickMode','manual',...                     
             'xtick',[1 10 100 1000]);
  end
    %  set(ph_axes,'FontWeight','bold')
    
    
 %-------------------   
 % Residual Figure:
 %---------------------
 %RHO
    figure(h_all_resid);
    indx = i;
    if indx>ceil(nsites/2);
        indx = indx+ceil(nsites/2);
    end
    rho_axes = subplot('position',[1/15+1/nsites*(i-1)*.9 .55 1/nsites-1/nsites*.10  .35]);
    if ~isempty(DTMr)
         semilogx(TTMr,(DTMr(:,1)-RTMr(:,1))./DTMr(:,2),'.r-');    
    end
    if ~isempty(DTMr); hold on; end
    if ~isempty(DTEr)
        semilogx(TTEr,(DTEr(:,1)-RTEr(:,1))./DTEr(:,2),'g.-'); 
    end
    if ~isempty(DTEr); hold on; end
    
    axis([Dlims(1) Dlims(2) -5 5]);
    if i == 1;
        ylabel('Ap. Res. Residual');
        set(rho_axes,'ygrid','off','xgrid','off');
    else  
        set(rho_axes,'ygrid','off','xgrid','off');
    end
    text = strcat(char(sites(i)));     %,': ',' TE = Green, TM = Red');
    title(text)
   %PHASE:
    ph_axes = subplot('position',[1/15+1/nsites*(i-1)*.9 .20 1/nsites-1/nsites*.10  .30]);
    if ~isempty(DTMp)
        semilogx(TTMp,(DTMp(:,1)-RTMp(:,1))./DTMp(:,2),'r.-');  
    end
    if ~isempty(DTMp); hold on; end
    if ~isempty(DTEp)
         semilogx(TTEp,(DTEp(:,1)-RTEp(:,1))./DTEp(:,2),'g.-'); 
    end
    axis([Dlims(1) Dlims(2) -5 5]);
    
    if i==1
        xlabel('Period (s)','FontSize',12);
        ylabel('Phase Residual');set(ph_axes,'ygrid','off','xgrid','off');
    else
      set(ph_axes,'ygrid','off','xgrid','off');
    end

  
  
   end
% END DATA STUFF

%--------------------------------------------------------------------------
function [lims,orient] = set_lims(dir,periods,rho)
%-------------------------------------------------------------------------- 
fid = fopen([dir '/limits.mat'],'r');
if(fid > 0 )
%   a limits file is found in the current directory; use this to define 
%   initial limits
   fclose(fid)
   eval( [ 'load ' dir '/limits.mat'] ) ;
elseif(nargin == 3 )
% use max/min limits of periods, rho to set limits
  x_min = min(periods);
  x_max = max(periods);
  xx_min = 10^(floor(log10(x_min)));
  if ((log10(x_min)-log10(xx_min)) < 0.15)
          xx_min = 10^(log10(xx_min)-0.3);
  end
  xx_max = 10^(ceil(log10(x_max)));
  if ((log10(xx_max)-log10(x_max)) < 0.15)
          xx_max = 10^(log10(xx_max)+0.3);
  end
  y_min = min(min(rho));
  y_max = max(max(rho));
  yy_min = 10^(floor(log10(y_min)));
  if ((log10(y_min)-log10(yy_min)) < 0.15)
          yy_min = 10^(log10(yy_min)-0.3);
  end
  yy_max = 10^(ceil(log10(y_max)));
  if ((log10(yy_max)-log10(y_max)) < 0.15)
          yy_max = 10^(log10(yy_max)+0.3);
  end
  lims = [xx_min, xx_max, yy_min, yy_max];
  orient = 0.;
else
% use some general limits
  lims = [.01,1000,1,10000];
  orient = 0.;
end

%--------------------------------------------------------------------------
function [xb,yb] = err_log(x,y,yerr,ll,lims,bAllowNeg)
%--------------------------------------------------------------------------
%err_log : used for plotting error bars with a y-axis log scale
%  takes VECTORS x and y and outputs matrices (one row per
% data point) for plotting error bars
%    ll = 'XLOG' for log X axis
%***********************************************************************

    n = size(x);
    xb = zeros(6,n(2));
    yb = zeros(6,n(2));
    barsize = .0075;
    if strcmpi(ll, 'XLOG');
      dx = log(lims(2)/lims(1))*barsize;
      xb(3,:)  = log(x);
      xb(4,:)  = xb(3,:);
      xb(1,:) = xb(3,:) - dx;
      xb(2,:) = xb(3,:) + dx;
      xb(5,:) = xb(3,:) - dx;
      xb(6,:) = xb(3,:) + dx;
      xb = exp(xb);
    else
      dx = (lims(2)-lims(1))*barsize;
      xb(3,:)  = x;
      xb(4,:)  = xb(3,:);
      xb(1,:) = xb(3,:) - dx;
      xb(2,:) = xb(3,:) + dx;
      xb(5,:) = xb(3,:) - dx;
      xb(6,:) = xb(3,:) + dx;
    end
    yb(1,:) = (y - yerr)';
    yb(2,:) = (y - yerr)';
    yb(3,:) = (y - yerr)';
    yb(4,:) = (y + yerr)';
    yb(5,:) = (y + yerr)';
    yb(6,:) = (y + yerr)';

    % DGM 10/6/05 Don't allow negative values!
    % DGM 8/7/06 By default, allow negatives.  This routine is used by many
    % different fctns and some of them expect this behavior.
    if exist('bAllowNeg','var') && ~bAllowNeg
        yb(:) = max(yb,lims(3)/10);
    end
    
return

%--------------------------------------------------------------------------
function [hfig] = getStackedFig( nSize )
%--------------------------------------------------------------------------
% getStackedFig() - return a new figure handle, stacked below the last
% active figure (gcf) or at the top/left if there are no figures open.
%
% David Myer, Oct 2005
%
% Params:
%   nSize   - (optional) if specified, should be 2 numbers to use as the
%           width & height of the window in pixels.
%----------------------------------------------------------------------

    % Force previous figures to finish showing so we can get accurate
    % positions.
    drawnow;
    
    nScrn = get(0, 'ScreenSize');
    nScrnRight = nScrn(3);
    nScrnTop   = nScrn(4);
    % There may be multiple screens or chopped off areas of the screen (such
    % as for the menu bar).  ScreenSize gives the full area of combined
    % screens, not the writable area of the main monitor.  Use
    % monitorposition instead.  Note that it gives left,top instead of
    % left,bottom like ScreenSize.
%     nMon = get(0,'monitorposition');
%     if size(nMon,1) > 1 
%         % n monitor system, use widest monitor
%         nMon = sortrows(nMon, -3); % sort descending by col 3 (width)
%         nMon = nMon(1,:);
%     end
%     nScrnRight = nMon(3) + nMon(1) - 1;
%     nScrnTop   = nMon(4) + nMon(2) - 1;
%     
%%BUG: if the 2nd monitor is *below* the primary, then nScrnTop is not high
%%enough.

%%BUG: if the 2nd monitor is *left* of the primary, then nScrnRight is not
%%far enough right and scrn left needs to be set.
    
    % get current figure's size or use bottom left corner
    f = get(0,'Currentfigure');
    if isempty(f)       % no figure open
        nPos = [1-22 1 0 0];
    else
        nPos = get( f, 'Position' );
    end
    nPos(1) = nPos(1) + 22;     % move to right
    nPos(2) = nPos(2) - 22;     % and down
    
    % Get new figure and its size.
    hfig = figure;
    if exist('nSize','var') && isnumeric(nSize) && length(nSize) == 2
        nPos(3:4) = nSize;
    else
        rect_win = get(hfig, 'Position' );
        nPos(3:4) = rect_win(3:4);
    end
    
    % If position is off right edge of the screen, move back to left,top
    if nPos(1) + nPos(3) > nScrnRight
        nPos(1) = 1;
        nPos(2) = -1;       % trigger repos of bottom.
    end
    
    % If position is off bottom, move back up to top
    if nPos(2) < 0
        nPos(2) = nScrnTop - nPos(4);
    end
    
    set( hfig, 'Position', nPos );

return;

%--------------------------------------------------------------------------
function [datfrm,datdes,nsites,sites,offsts,nfre,freqs, ...
        ndblks,DATA]= readDATA(datfile)
%--------------------------------------------------------------------------
% function readDATA.m
% Version 1.0, July 2001
% Written by: Kerry Key IGPP/SIO/UCSD
% 
% A matlab script to read an OCCAM2DMT DATA file
%
% Usage: 
%        [datfrm,datdes,nsites,sites,offsts,nfre,freqs, ...
%         ndblks,DATA]= readDATA(datfile);
%
% Inputs
%        datfile: OCCAM2DMT DATA file name (string format)
%
% Outputs: 
% 		datfrm
% 		datdes
% 		nsites
% 		sites(nsites)
% 		offsts(nsites)
% 		nfre:            Also can be found in MESH FILE, if running FWD PW2D 
% 		freqs(nfre):     Also can be found in  MESH FILE, if running FWD PW2D
% 		ndblks:          Number of data blocks
% 		DATA(ndblks,5):  Ndblks by [SITE  FREQ#  TYPE  DATUM  ERR]
%
%--------------------------------------------------------------------------


% OPEN AND READ IN DATA FILE (to get site offsets):
   fiddat = fopen(datfile,'r');
    cline  = fgets(fiddat);  
   datfrm = sscanf(cline,'FORMAT:           %80c');
   if  strcmp(deblank(datfrm),'OCCAM2DMTDATA_2.0')
      ndp = 4;
   else
       ndp =3;
   end
   
    cline  = fgets(fiddat); 
   datdes = sscanf(cline,'DESCRIPTION:      %80c');
    cline  = fgets(fiddat); 
   nsites = sscanf(cline,'SITES:            %f');
   for i  = 1:nsites
       cline    = fgets(fiddat);
      sites(i) = cellstr(sscanf(cline,'%s'));
   end
   string = fgets(fiddat);   %#ok<NASGU>
   offsts = fscanf(fiddat,'%f',nsites);
    cline  = fgets(fiddat);  %#ok<NASGU>
    cline  = fgetl(fiddat); 
   nfre   = sscanf(cline,'FREQUENCIES:%f');
   freqs  = fscanf(fiddat,'%f',nfre);
    cline  = fgets(fiddat); %#ok<NASGU>
    cline  = fgets(fiddat);
   ndblks = sscanf(cline,'DATA BLOCKS:%f');
    string = fgets(fiddat); %#ok<NASGU>
   DATA   = fscanf(fiddat,'%f %f %f %f %f',[ndp+2 ndblks]);
   DATA=DATA';
   fclose(fiddat);
   
